@@ -14,6 +14,7 @@ def import_class(name):
     cls = getattr(mod, components[-1])
     return cls
 
+
 def get_policy_class():
     #
     # returns policy class
@@ -24,6 +25,20 @@ def get_policy_class():
 
     return Policy
 
+
+def get_all_stages():
+    #
+    # returns list of all stages
+    #
+
+    if current_app.config.get('METHOD_GET_STAGES'):
+        lClass = import_class(current_app.config.get('METHOD_GET_STAGES'))()
+        return lClass.getAllStages
+        # return import_class(current_app.config.get('METHOD_GET_STAGES'))
+
+    raise Exception('Method to Get Stages NOT defined')
+
+
 def get_activity_class(activity_type_class):
     #
     # returns activity class
